/* * This file is part of Harmattan Organiser GUI *
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 *
 * Contact: Andrey Moiseenko <andrey.moiseenko@nokia.com>
 *
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved. Copying,
 * including reproducing, storing, adapting or translating, any or all of
 * this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */
/**
 * @file
 * \brief This file defines an abstract base class for note widget views.
 *
 * @author Mikko Herranen \<ext-mikko.herranen@nokia.com\>
 */
#ifndef ABSTRACTNOTEWIDGETVIEW_H
#define ABSTRACTNOTEWIDGETVIEW_H

#include <MWidgetView>

#include "organiser_export.h"
#include "notewidget.h"
#include "notewidgetmodel.h"
#include "notewidgetstyle.h"

/**
 * \brief An abstract base class for note widget views.
 *
 * This class is responsible for drawing the alarm icon and color stripe.
 */
class ORGANISER_EXPORT AbstractNoteWidgetView : public MWidgetView
{
  Q_OBJECT
  M_VIEW(NoteWidgetModel, NoteWidgetStyle)

public:
  /**
   * \brief Constructor.
   *
   * \param controller Pointer to controller class instance.
   */
  AbstractNoteWidgetView(NoteWidget* controller);

  /**
   * \brief Destructor.
   */
  virtual ~AbstractNoteWidgetView();

protected:
  //! \reimp
  /**
   * \brief Draw background from cache.
   *
   * If the background is not in cache, draw and cache the result. Cached
   * backgrounds are shared between widget instances.
   */
  virtual void drawBackground(QPainter* painter, const QStyleOptionGraphicsItem* option) const;

  
  virtual void setupModel();
  //! \reimp_end

private:
  Q_DISABLE_COPY(AbstractNoteWidgetView);

protected Q_SLOTS:
  //! \reimp
  virtual void updateData(const QList<const char*>& modifications);
  //! \reimp_end

};

#endif
