/* * This file is part of Harmattan Organiser GUI *
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 *
 * Contact: Andrey Moiseenko <andrey.moiseenko@nokia.com>
 *
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved. Copying,
 * including reproducing, storing, adapting or translating, any or all of
 * this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */
/**
 * @file
 * This file contains private definitions for the CalendarConf class.
 *
 * @author Mikko Herranen \<ext-mikko.herranen@nokia.com\>
 */
#ifndef CALENDARCONF_P_H
#define CALENDARCONF_P_H

// Settings file configuration ~/.config/Nokia/organiser_settings.conf
#define ORGANISER_CONF_ORG "Nokia"
#define ORGANISER_CONF_APP "organiser_settings"

//Calendar values
#define CONFKEY_TIMEZONE_SUPPORT "timezone_support"
#define CONFKEY_WORKING_DAYS_MASK "working_days_mask"
#define CONFKEY_HIDE_COMPLETED_TODOS "hide_completed_todos"
#define CONFKEY_FIRST_DAY_OF_WEEK "first_day_of_week"
#define CONFKEY_DEFAULT_REMINDER "default_reminder"
#define CONFKEY_HAS_DEFAULT_REMINDER "has_default_reminder"
#define CONFKEY_LAST_ACTIVE_TAB "last_active_tab"
#define CONFKEY_WEEK_VIEW_DAYS_P "week_view_days_p"
#define CONFKEY_WEEK_VIEW_DAYS_L "week_view_days_l"
#define CONFKEY_FIRST_RUN_FLAG "first_run"

//Notes values
#define CONFKEY_NOTES_WITH_CONTENT "notes_content"

// Default values
#define CONFKEY_TIMEZONE_SUPPORT_DEFAULT_VALUE        false
#define CONFKEY_WORKING_DAYS_MASK_DEFAULT_VALUE       -1
#define CONFKEY_HIDE_COMPLETED_TODOS_DEFAULT_VALUE    false
#define CONFKEY_FIRST_DAY_OF_WEEK_DEFAULT_VALUE       -1
#define CONFKEY_DEFAULT_REMINDER_DEFAULT_VALUE        15
#define CONFKEY_HAS_DEFAULT_REMINDER_DEFAULT_VALUE    true
#define CONFKEY_LAST_ACTIVE_TAB_DEFAULT_VALUE         0
#define CONFKEY_WEEK_VIEW_DAYS_P_DEFAULT_VALUE        1
#define CONFKEY_WEEK_VIEW_DAYS_L_DEFAULT_VALUE        7
#define CONFKEY_FIRST_RUN_FLAG_DEFAULT_VALUE          true
#define CONFKEY_NOTES_WITH_CONTENT_VALUE              false

class CalendarConf;
class QString;
class QTimer;
class QSettings;
class QFileSystemWatcher;


class CalendarConfPrivate
{
public:
  CalendarConfPrivate(CalendarConf* p);
  ~CalendarConfPrivate();

  void syncSettings();

  QSettings* calSettings;
  QFileSystemWatcher* settingsWatcher;
  QTimer* syncSingleShot;

private:
  Q_DECLARE_PUBLIC(CalendarConf);
  Q_DISABLE_COPY(CalendarConfPrivate);
  CalendarConf* q_ptr;

};

#endif
