/* * This file is part of Harmattan Organiser GUI *
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 *
 * Contact: Andrey Moiseenko <andrey.moiseenko@nokia.com>
 *
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved. Copying,
 * including reproducing, storing, adapting or translating, any or all of
 * this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */
/**
 * @file
 * \brief This file defines private part of DbInstance class.
 *
 * @author Mikko Herranen \<ext-mikko.herranen@nokia.com\>
 */
#ifndef DB_INSTANCE_P_H
#define DB_INSTANCE_P_H

#include <extendedcalendar.h>
#include <timed/interface.h>
#include <QFutureWatcher>
#include "db_instance.h"

/**
 * \brief Private part of DbInstance class.
 */
class DbInstancePrivate
{
public:

  /**
   * \brief Constructor.
   *
   * \param p Pointer to public class.
   */
  DbInstancePrivate(DbInstance* p);

  /**
   * \brief Opens the storage.
   */
  void openStorage();

  /**
   * \brief Cleans up the internal range cache
   */
  void cleanUpCache();

  /**
   * \brief Initial DB load for Calendar
   */
  void initialLoad();

  /**
   * \brief Initial DB load for Notes
   */
  void initialNotesLoad();

  /**
   * \brief Create the dafault calendar
  */
  void createDefaultCalendar();

  /**
   * \brief Create calendar only for notes
  */
  void createNotesCalendar();

  /**
   * \brief Reset all the alarms of all incidences
  */
  void resetAllAlarms();

  /**
   * \brief Destructor.
   */
  ~DbInstancePrivate();

  mKCal::ExtendedCalendar::Ptr calendar;
  mKCal::ExtendedStorage::Ptr storage;
  Maemo::Timed::Interface timed_interface;
  bool open_succeeded;
  QDate startRange;
  QDate endRange;
  bool recurringIncidences;
  bool uncompletedTodos;
  bool dbEnabled;
  QFutureWatcher<void> dbWatcher;
  QFuture<void> dbFuture;
  bool threadedInit;
  bool pendingSave;
  bool journalsLoaded;
  DbInstance::DbUser mUserType;
  mKCal::Notebook::Ptr notebookPendingUpdate;
  bool ownSave;

private:
  Q_DISABLE_COPY(DbInstancePrivate);
  Q_DECLARE_PUBLIC(DbInstance);

  DbInstance* q_ptr;

};

#endif
