/* * This file is part of Harmattan Organiser GUI *
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 *
 * Contact: Andrey Moiseenko <andrey.moiseenko@nokia.com>
 *
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved. Copying,
 * including reproducing, storing, adapting or translating, any or all of
 * this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */
/**
 * @file
 * \brief This file defines private part of ExpandedIncidencesCache class.
 *
 * @author Alvaro Manera \<alvaro.manera@nokia.com\>
 */
#ifndef EXPANDEDCACHE_P_H
#define EXPANDEDCACHE_P_H

#include <QDate>
#include <extendedcalendar.h>

class ExpandedIncidencesCache;

class ExpandedCachePrivate {

public:

    enum Direction {
        Append,
        Prepend
    };

    /**
     * \brief Constructor.
     *
     * \param p Pointer to public class.
     */
    ExpandedCachePrivate(ExpandedIncidencesCache* p);

    /**
     * Is the range given contiguous to the cache one?
     * \param start The start of the range to check
     * \param end The end of the range to check
     * \param newStart by ref. The new start you need to query to DB
     * \param newEnd by ref The new end to query
     * \return True if contiguous and you ned to query DB with the new range
     */
    bool contiguousRange(const QDate &start, const QDate &end, QDate  &newStart, QDate &newEnd, Direction &dir);

    bool appendExpandedIncidences(const QDate &start, const QDate &end);
    bool prependExpandedIncidences(const QDate &start, const QDate &end);

    KCalCore::Incidence::List loadEventsTodos(const QDate &start, const QDate &end);

    QDate mStart;
    QDate mEnd;
    bool mCached; //if there is something in cache

    mKCal::ExtendedCalendar::ExpandedIncidenceList mList;

    ExpandedIncidencesCache* q_ptr;

};

#endif // EXPANDEDCACHE_P_H
