#ifndef EXPANDEDINCIDENCESCACHE_H
#define EXPANDEDINCIDENCESCACHE_H

#include <QObject>
#include <QDate>

#include <extendedcalendar.h>
#include "organiser_export.h"

class ExpandedCachePrivate;

using namespace mKCal;

class ORGANISER_EXPORT ExpandedIncidencesCache : public QObject
{
    Q_OBJECT
public:
    /**
     * \brief Get a singleton instance of the class.
     */
    static ExpandedIncidencesCache& instance();

    /**
     * \brief Make the initial load and expansion of incidences.
     * Takes the centerDate and loads all the possible dates you can
     * see in a month grid which contains those dates
     * \warning Calling this method clears the previous cache
     * \warning Start has to be always smaller than end. If not, undefined behavior!
     * \param The center date to start expanding from
     * \return The expanded list
     */
    ExtendedCalendar::ExpandedIncidenceList loadExpandedEventsAndTodos(const QDate &start, const QDate &end);


    /**
     * \brief Get a range of the expanded incidences.
     * If it is in the cache it will be returned almost right away, if not
     * it is expanded, cached and returned
     * \param start the start date
     * \param end where you want to stop getting expanded dates
     * \warning Start has to be always smaller than end. If not, undefined behavior!
     * \return the famous expanded list of incidences
     */
    ExtendedCalendar::ExpandedIncidenceList getExpandedEventsAndTodos(const QDate &start, const QDate &end);


    /**
     * \brief Dumps all the cache from memory
     */
    void clearExpandedIncidences();

    /**
     * \brief The cache is not valid due to a change in storare, and we want to reload whatever we had
     */
    void reloadCache();




signals:

public slots:

private:
    Q_DISABLE_COPY(ExpandedIncidencesCache);
    Q_DECLARE_PRIVATE(ExpandedCache);
    ExpandedIncidencesCache();

    ~ExpandedIncidencesCache();

    ExpandedCachePrivate *d_ptr;
};

#endif // EXPANDEDINCIDENCESCACHE_H
