/* * This file is part of Harmattan Organiser GUI *
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 *
 * Contact: Andrey Moiseenko <andrey.moiseenko@nokia.com>
 *
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved. Copying,
 * including reproducing, storing, adapting or translating, any or all of
 * this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */
/**
 * @file
 * \brief This file defines the view for MultiStateWidget.
 *
 * @author Mikko Herranen \<ext-mikko.herranen@nokia.com\>
 */
#ifndef MULTISTATEWIDGETVIEW_H
#define MULTISTATEWIDGETVIEW_H

#include <MWidgetView>
#include <QObject>

#include "multistatewidgetmodel.h"
#include "multistatewidgetstyle.h"

class MultiStateWidget;
class MultiStateWidgetViewPrivate;

/**
 * \brief
 * View class for MultiStateWidget.
 */
class MultiStateWidgetView : public MWidgetView
{
  Q_OBJECT
  M_VIEW(MultiStateWidgetModel, MultiStateWidgetStyle)

public:
  /**
   * \brief Constructor.
   *
   * @param controller Pointer to the controller class.
   */
  MultiStateWidgetView(MultiStateWidget* controller);

  /**
   * \brief Destructor.
   */
  virtual ~MultiStateWidgetView();

protected:
  MultiStateWidgetViewPrivate* d_ptr;

  //! \reimp
  virtual void applyStyle();
  virtual void setupModel();
  //! \reimp_end

private:
  Q_DISABLE_COPY(MultiStateWidgetView);
  Q_DECLARE_PRIVATE(MultiStateWidgetView);

protected slots:
  //! \reimp
  virtual void updateData(const QList<const char*>& modifications);
  //! \reimp_end

  void orientationChanged(const M::Orientation& orientation);

};

#endif
