/* * This file is part of Harmattan Organiser GUI *
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 *
 * Contact: Andrey Moiseenko <andrey.moiseenko@nokia.com>
 *
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved. Copying,
 * including reproducing, storing, adapting or translating, any or all of
 * this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */

/**
 * @file
 * \brief Main header file for controller of widget to add or edit a notebook.
 *
 * @author Kristoffer Lawson \<ext-kristoffer.lawson@nokia.com\>
 * @author Tuomas Toivonen \<ext-tuomas.1.toivonen@nokia.com\>
 */

#ifndef NOTEBOOKEDITWIDGET_H
#define NOTEBOOKEDITWIDGET_H

#include <MWidgetController>
#include <QObject>

#include "notebookeditwidgetmodel.h"
#include "pageswitcher.h"
#include "notebookmanager.h"
#include "organiser_export.h"

class NotebookEditWidgetPrivate;

/**
 * \brief
 * Controller for widget to add a new notebook.
 */
class NotebookEditWidget : public MWidgetController,
  public PageSwitchObserverIface

{
  Q_OBJECT
  M_CONTROLLER(NotebookEditWidget)

public:

  /**
   * \brief Constructs a new widget.
   */
  NotebookEditWidget(MWidget* parent = 0);

  /**
   * \brief Destructor.
   */
  ~NotebookEditWidget();

  bool backClicked();

  /**
   * \brief Setup widget so it is creating new notebook.
   */
  void newNotebook();

  /**
   * \brief Get widget's notebook
   */
  mKCal::Notebook::Ptr notebook();

  /**
   * \brief Setup widget so it is editing previous notebook.
   */
  void setNotebook(const mKCal::Notebook::Ptr &notebook);

  /**
   * \brief Load notebook from db to model.
   */
  void loadNotebookToModel(const mKCal::Notebook::Ptr &notebook);

  /**
   * \brief Save notebook to db from model.
   */
  void saveNotebookFromModel();

  /**
   * \brief Return the next available (unused) notebook color.
   */
  QColor getNextAvailableColor();

  /**
   * \brief Signal view to set focus on text field.
   */
  void setFocusOnText();

  /**
   * \brief Signal clients that save notebook is available.
   */
  void setCanSave(bool canSave);

  /**
   * \brief Colors to use for notebooks.
   */
  QList<QColor> notebookColors;

  /**
   * \brief Order for selecting default colors for notebooks.
   */
  QList<int> defaultColorOrder;

signals:

  /**
   * \brief Sent if a delete button was clicked.
   */
  void notebookDeleted();

  /**
   * \brief Emitted to set focus on required text field
   */
  void focusOnText();

  /**
   * \brief Emitted when you have something to save.
   */
  void canSaveNotebook(bool canSave);

private:
  Q_DISABLE_COPY(NotebookEditWidget);
  Q_DECLARE_PRIVATE(NotebookEditWidget);
  NotebookEditWidgetPrivate* d_ptr;

};

#endif

