/* * This file is part of Harmattan Organiser GUI *
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 *
 * Contact: Andrey Moiseenko <andrey.moiseenko@nokia.com>
 *
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved. Copying,
 * including reproducing, storing, adapting or translating, any or all of
 * this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */
/**
 * @file
 * \brief View for a widget which allows user to create or edit a calendar.
 *
 * @author Kristoffer Lawson \<ext-kristoffer.lawson@nokia.com\>
 * @author Tuomas Toivonen \<ext-tuomas.1.toivonen@nokia.com\>
 */
#ifndef NOTEBOOKEDITWIDGETVIEW_H
#define NOTEBOOKEDITWIDGETVIEW_H

#include <MWidgetStyle>
#include <MWidgetView>
#include <MLabel>

#include "notebookeditwidgetmodel.h"
#include "notebookeditwidgetstyle.h"
#include "notebookeditwidget.h"

class NotebookEditWidgetViewPrivate;

/**
 * \brief View class for NotebookEditWidget.
 */
class NotebookEditWidgetView : public MWidgetView
{
  Q_OBJECT
  M_VIEW(NotebookEditWidgetModel, NotebookEditWidgetStyle)

public:
  /**
   * \brief Constructor.
   */
  NotebookEditWidgetView(NotebookEditWidget* controller);

  /**
   * \brief Destructor.
   */
  virtual ~NotebookEditWidgetView();

  void updateData(const QList<const char*>& modifications);

protected:

  //! \reimp
  virtual void applyStyle();
  virtual void setupModel();
  //! \reimp_end

private:
  Q_DISABLE_COPY(NotebookEditWidgetView);
  Q_DECLARE_PRIVATE(NotebookEditWidgetView);
  NotebookEditWidgetViewPrivate* d_ptr;

private slots:
  void colorPicked();
  void titleTextChanged();
  void titleTextUpdated();
  void showSynchronization();
  void visibilitySwitchButtonToggled(bool selected);
  void defaultNotebookSwitchButtonToggled(bool selected);
  void notebookColorButtonClicked();
  void focusOnText();
  void textFieldReturnPressed();
};

#endif
