/* * This file is part of Harmattan Organiser GUI *
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 *
 * Contact: Andrey Moiseenko <andrey.moiseenko@nokia.com>
 *
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved. Copying,
 * including reproducing, storing, adapting or translating, any or all of
 * this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */

/**
 * @file
 * Private data for view for widget that creates or edits notebooks.
 *
 * @author Kristoffer Lawson \<ext-kristoffer.lawson@nokia.com\>
 * @author Tuomas Toivonen \<ext-tuomas.1.toivonen@nokia.com\>
 */

#ifndef NOTEBOOKEDITWIDGETVIEW_P_H
#define NOTEBOOKEDITWIDGETVIEW_P_H

#include <MGridLayoutPolicy>
#include <MLayout>
#include <MTextEdit>
#include <MDialog>
#include <QGraphicsLinearLayout>

#include "organiserutility.h"
#include "colorpickerwidget.h"
#include "multistatewidget.h"

class MSyncWidget;
class NotebookEditWidget;
class NotebookEditWidgetView;
class MultiStateWidget;
class NotebookWidgetColorView;

/**
 * \brief Private part of NotebookEditWidgetView.
 */
class NotebookEditWidgetViewPrivate
{

public:

  /**
   * \brief Constructor.
   *
   * \param p Pointer to the public class.
   * \param controller Pointer to controller class instance.
   */
  NotebookEditWidgetViewPrivate(NotebookEditWidgetView* p, 
				NotebookEditWidget* controller);

  /**
   * \brief Destructor.
   */
  ~NotebookEditWidgetViewPrivate();

  NotebookEditWidget* controller;

  void configureVKB();

  /**
   * \brief Widget main layout.
   */
  MLinearLayoutPolicy* layoutPolicy;

  /**
   * \brief Header label
   */
  MLabel* headerLabel;

  /**
   * \brief Title input
   */
  MTextEdit* titleTextEdit;

  MStylableWidget* noticeDefCalWidget;

  /**
   * \brief Label to indicate the notebook's color.
   */
  NotebookWidgetColorView *colorSelectorView;

  /**
   * \brief Pick colour of widget.
   */
  ColorPickerWidget* colorPicker;

  /**
   * \brief Dialog to select color of the notebook.
   */
  MDialog* colorSelectionDialog;

  /**
   * \brief Button to toggle notebook visibility settings.
   */
  MButton* visibilitySwitchButton;

  /**
   * \brief Button to toggle whether this notebook is default or not.
   */
  MButton* defaultNotebookSwitchButton;

  /**
   * \brief Label that shows the number of events the notebook has.
   */
  MLabel* eventCountLabel;

  /**
   * \brief Label that shows the number of todos the notebook has.
   */
  MLabel* todoCountLabel;

  /**
   * \brief Label that shows the number of journals the notebook has.
   */
  MLabel* journalCountLabel;

  /**
   * \brief Container for sync widget.
   */
  QGraphicsLinearLayout* syncWidgetContainer;
  MWidget* syncWidgetContainerWidget;

  /**
   * \brief Sync widget.
   */
  MSyncWidget* syncWidget;

  /**
   * \brief Delete button for local notebooks(except personal).
   */
  MButton* deleteButton;

  /**
   * \brief Update the labels showing incidence counts for this notebook.
   */
  void updateIncidenceCounts();

  /**
   * \brief Update the visibility switch for the notebook.
   */
  void updateVisibility();

  /**
   * \brief Update the default notebook switch for the notebook.
   */
  void updateDefaultNotebook();

  /**
   * \brief Update the title of the notebook.
   */
  void updateTitle();

  /**
   * \brief Update the color of the notebook.
   */
  void updateColor();

  /**
   * \brief Update the sync widget if this is a service notebook.
   */
  void updateSyncWidget();

  /**
   * \brief Update the id of the notebook.
   */
  void updateNotebookId();

  /**
   * \brief Update the text of view header.
   */
  void updateHeader();

  /**
   * \brief Update focus.
   */
  void updateFocus();

  /**
   * \brief Update delete buttons state.
   */
  void updateDeleteButton();

private:
  NotebookEditWidgetView* q_ptr;
  Q_DISABLE_COPY(NotebookEditWidgetViewPrivate);
  Q_DECLARE_PUBLIC(NotebookEditWidgetView);
  QGraphicsLayout* createTitledItem(const QString& title,
                                        QGraphicsLayoutItem* item, QGraphicsWidget* parent);
  MWidget* createItemDivider(QGraphicsItem* parent);
};

#endif
