/* * This file is part of Harmattan Organiser GUI *
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 *
 * Contact: Andrey Moiseenko <andrey.moiseenko@nokia.com>
 *
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved. Copying,
 * including reproducing, storing, adapting or translating, any or all of
 * this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */
/**
 * @file
 * \brief This file defines the Manage Calendars widget.
 *
 * @author Kristoffer Lawson \<ext-kristoffer.lawson@nokia.com\>
 */
#ifndef NOTEBOOKMANAGEMENTWIDGET_H
#define NOTEBOOKMANAGEMENTWIDGET_H

#include <MWidgetController>
#include <QObject>
#include <QModelIndex>
#include <MApplicationWindow>

#include "notebookmanagementwidgetmodel.h"
#include "notebookeditwidget.h"
#include "organiserutility.h"
#include "pageswitcher.h"
#include "organiser_export.h"

class NotebookManagementWidgetPrivate;

/**
 * \brief
 * List of available notebooks, and manipulation
 */
class ORGANISER_EXPORT NotebookManagementWidget : public MWidgetController,
                                 public VisibilityNotificationIF
{
  Q_OBJECT
  M_CONTROLLER(NotebookManagementWidget)

public:

  /**
   * \brief Constructs a new widget.
   */
  NotebookManagementWidget();

  /**
   * \brief Destructor.
   */
  ~NotebookManagementWidget();

protected:
  void updateContent(int);
  int updateTypeMask();

private:
  Q_DISABLE_COPY(NotebookManagementWidget);
  Q_DECLARE_PRIVATE(NotebookManagementWidget);
  NotebookManagementWidgetPrivate* d_ptr;

signals:

public slots:

  /**
   * Should be called when the user has selected to create a device
   * (local) calendar.
   */
  void createDeviceNotebook();

  /**
   * Should be called when the user has selected to create a service
   * (remote) calendar.
   */
  void createServiceNotebook(const QString& syncProfile,
                             const QString& pluginName,
                             const QString& account,
                             bool canShareNotebooks);

  void deleteNotebook();

  void deleteNotebook(const QString& notebookId);

  void notebookSelected(const QString& notebookId);

  void changeNotebookVisibility(const QString& notebookId, bool visible);

  /**
   * \brief Called when user selects to create a new notebook.
   */
  void createNewNotebook();

private slots:
  void newNotebookTypeSelected(const QModelIndex& index);
  void cancelEdit();
  void saveEdit();
  void handleDeleteNotebook(int buttonId);
  void handleDeleteNotebookId(int buttonId);
  void initNewNotebookPageFocus();
  void updateSaveButton(bool canSave);
};

#endif
