/* * This file is part of Harmattan Organiser GUI *
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 *
 * Contact: Andrey Moiseenko <andrey.moiseenko@nokia.com>
 *
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved. Copying,
 * including reproducing, storing, adapting or translating, any or all of
 * this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */

/**
 * @file
 * \brief This file contains the private part of Notebook Management Widget
 *
 * @author Kristoffer Lawson \<ext-kristoffer.lawson@nokia.com\>
 */

#ifndef NOTEBOOKMANAGEMENTWIDGET_P_H
#define NOTEBOOKMANAGEMENTWIDGET_P_H

#include <QObject>
#include "notebookeditwidget.h"

class NotebookManagementWidget;
class MList;
class MDialog;
class ServiceCalendarListModel;

/**
 * \brief Private part of the NotebookManagementWidgetWidget controller.
 */
class NotebookManagementWidgetPrivate
{
public:
  /**
   * \brief Constructor.
   *
   * @param p Pointer to the public controller class.
   */
  NotebookManagementWidgetPrivate(NotebookManagementWidget* p);

  /**
   * \brief Destructor.
   */
  virtual ~NotebookManagementWidgetPrivate();

#ifdef SERVICE_CALENDAR_SUPPORT
  /**
   * \brief Initialize.
   */
  void init();
#endif // SERVICE_CALENDAR_SUPPORT

  void initNotebookEditPage();

  LazyLoadSheet<NotebookEditWidget>* notebookEditPage;

#ifdef SERVICE_CALENDAR_SUPPORT
  /**
   * \brief Dialog for creating new notebooks.
   */
  MDialog* newNotebookDialog;

  /**
   * \brief Service calendar accounts list.
   */
  MList* servicesList;

  /**
   * \brief Model for service calendar accounts list.
   */
  ServiceCalendarListModel* servicesModel;

#endif // SERVICE_CALENDAR_SUPPORT


protected:
  Q_DECLARE_PUBLIC(NotebookManagementWidget);
  Q_DISABLE_COPY(NotebookManagementWidgetPrivate);
  NotebookManagementWidget* q_ptr;

  QString mDeleteNotebookId;
};

#endif
