/* * This file is part of Harmattan Organiser GUI *
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 *
 * Contact: Andrey Moiseenko <andrey.moiseenko@nokia.com>
 *
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved. Copying,
 * including reproducing, storing, adapting or translating, any or all of
 * this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */
/**
 * @file
 * \brief This file defines the view for the notebook management widget.
 *
 * @author Kristoffer Lawson \<ext-kristoffer.lawson@nokia.com\>
 * @author Kristoffer Lawson \<ext-tuomas.1.toivonen@nokia.com\>
 */
#ifndef NOTEBOOKMANAGEMENTWIDGETVIEW_H
#define NOTEBOOKMANAGEMENTWIDGETVIEW_H

#include <QGraphicsGridLayout>

#include <MCalendar>
#include <MWidgetStyle>
#include <MWidgetView>
#include <MLabel>

#include "notebookmanagementwidgetmodel.h"
#include "notebookmanagementwidgetstyle.h"
#include "notebookmanagementwidget.h"

class NotebookManagementWidgetViewPrivate;

/**
 * \brief View class for NotebookManagementWidget.
 */
class NotebookManagementWidgetView : public MWidgetView
{
  Q_OBJECT
  M_VIEW(NotebookManagementWidgetModel, NotebookManagementWidgetStyle)

public:
  /**
   * \brief Constructor.
   */
  NotebookManagementWidgetView(NotebookManagementWidget* controller);

  /**
   * \brief Destructor.
   */
  virtual ~NotebookManagementWidgetView();

protected:
  //! \reimp
  virtual void applyStyle();
  virtual void setupModel();
  //! \reimp_end

private:
  Q_DISABLE_COPY(NotebookManagementWidgetView);
  Q_DECLARE_PRIVATE(NotebookManagementWidgetView);
  NotebookManagementWidgetViewPrivate* d_ptr;

protected slots:
  //! \reimp
  virtual void updateData(const QList<const char*>& modifications);
  //! \reimp_end
};


/**
 * \brief Notebook list header widget.
 */
class NotebookListHeaderWidget : public MStylableWidget
{
    Q_OBJECT
public:
    /**
     * \brief Constructs a new header widget.
     */
    NotebookListHeaderWidget(QGraphicsItem *parent = 0)
        : MStylableWidget(parent), label(new MLabel(this))
    {
        setStyleName("CommonGroupHeaderPanel");

        QGraphicsGridLayout* layout = new QGraphicsGridLayout();
        organiserUtilityResetLayoutMargingsAndSpacing(layout);
        setLayout(layout);

        layout->addItem(organiserUtilityCreateSeparator(this, "CommonGroupHeaderDivider"), 0, 0, Qt::AlignCenter);
        layout->setColumnStretchFactor(0, 1);

        label->setStyleName("CommonGroupHeader");
        layout->addItem(label, 0, 1, Qt::AlignCenter);
    }

    /**
     * \brief Destructs the header widget.
     */
    ~NotebookListHeaderWidget()
    {
        if (label) {
            delete label;
        }
    }

    /**
     * \brief Get the text of the header.
     */
    QString text() const
    {
        return label->text();
    }

    /**
     * \brief Set the text of the header.
     */
    void setText(const QString& text)
    {
        label->setText(text);
    }

private:
    MLabel* label;
};

#endif
