/* * This file is part of Harmattan Organiser GUI *
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 *
 * Contact: Andrey Moiseenko <andrey.moiseenko@nokia.com>
 *
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved. Copying,
 * including reproducing, storing, adapting or translating, any or all of
 * this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */

/**
 * @file
 * This file contains the private part of view for managing notebooks.
 *
 * @author Kristoffer Lawson \<ext-kristoffer.lawson@nokia.com\>
 */

#ifndef NOTEBOOKMANAGEMENTWIDGETVIEW_P_H
#define NOTEBOOKMANAGEMENTWIDGETVIEW_P_H

#include <MGridLayoutPolicy>
#include <MLayout>
#include <MList>

#include "notebookmanager.h"
#include "abstractstringlistmodel.h"

class NotebookManagementWidget;
class NotebookManagementWidgetView;

class ServiceCalendarListModel; // in notebookmanagementwidgetview.cpp

/**
 * \brief Private part of NotebookManagementWidgetView.
 */
class NotebookManagementWidgetViewPrivate
{

public:
  /**
   * \brief Constructor.
   *
   * \param p Pointer to the public class.
   * \param controller Pointer to controller class instance.
   */
  NotebookManagementWidgetViewPrivate(NotebookManagementWidgetView* p, NotebookManagementWidget* controller);

  /**
   * \brief Destructor.
   */
  ~NotebookManagementWidgetViewPrivate();
  
  NotebookManagementWidget* controller;

  /**
   * \brief Widget main layout.
   */
  MLayout* layout;

  /**
   * \brief The layout policy used for portrait and landscape.
   */
  MGridLayoutPolicy* layoutPolicy;

  /**
   * \brief List of notebooks.
   */
  MList* notebookList;

  /**
   * \brief Item model for list of notebooks.
   */
  AbstractStringListModel* notebookListModel;

  /**
   * \brief Updates the notebooks from the model.
   */
  void updateNotebookList();

private:
  NotebookManagementWidgetView* q_ptr;
  Q_DISABLE_COPY(NotebookManagementWidgetViewPrivate);
  Q_DECLARE_PUBLIC(NotebookManagementWidgetView);

protected slots:

};



#endif

