/* * This file is part of Harmattan Organiser GUI *
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 *
 * Contact: Andrey Moiseenko <andrey.moiseenko@nokia.com>
 *
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved. Copying,
 * including reproducing, storing, adapting or translating, any or all of
 * this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */

/**
 * @file
 * A skeleton for creating the private part of view.
 *
 * @author Markus Stenberg \<ext-markus.stenberg@nokia.com\>
 */

#ifndef NOTEBOOKWIDGETPICKERVIEW_P_H
#define NOTEBOOKWIDGETPICKERVIEW_P_H

#include <QStringList>

class NotebookWidgetPicker;
class NotebookWidgetPickerView;
class MyColorLabel;
class NotebookWidget;
class MImageWidget;
class MDialog;
class MLabel;
class MList;

/**
 * \brief Private part of NotebookWidgetPickerView.
 */
class NotebookWidgetPickerViewPrivate
{
private:
  NotebookWidgetPickerView* q_ptr;
  Q_DISABLE_COPY(NotebookWidgetPickerViewPrivate);
  Q_DECLARE_PUBLIC(NotebookWidgetPickerView);

public:
  /**
   * \brief Constructor.
   *
   * \param p Pointer to the public class.
   * \param controller Pointer to controller class instance.
   */
  NotebookWidgetPickerViewPrivate(NotebookWidgetPickerView* p, NotebookWidget* controller);

  /**
   * \brief Destructor.
   */
  ~NotebookWidgetPickerViewPrivate();

  /**
   * \brief Get the list of notebook Ids corresponding to the model's ids.
   */
  QStringList notebookIds();

  /**
   * \brief Update selected notebook id.
   */
  void updateNotebookId();

  /**
   * \brief Update selected notebook name.
   */
  void updateNotebookName();

  /**
   * \brief Update notebook list.
   */
  void updateNotebookList();

private:

  NotebookWidget* controller;

  MDialog* notebookSelectorPopupListDialog;

  MList* notebookSelectorList;

  MImageWidget* mainIcon;

  MyColorLabel* notebookColor;

  MLabel* notebookName;
};

#endif


