/* * This file is part of Harmattan Organiser GUI *
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 *
 * Contact: Andrey Moiseenko <andrey.moiseenko@nokia.com>
 *
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved. Copying,
 * including reproducing, storing, adapting or translating, any or all of
 * this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */
/**
 * @file
 *
 * \brief This is a NotebookWidget subview that presents notebook name
 * on the left, notebook color box on the right, and allows selection
 * of another notebook using the box.
 *
 * @author Markus Stenberg \<ext-markus.stenberg@nokia.com\>
 */
#ifndef NOTEBOOKWIDGETSETTINGSVIEW_H
#define NOTEBOOKWIDGETSETTINGSVIEW_H

#include <MCalendar>
#include <MWidgetStyle>
#include <MWidgetView>
#include <QModelIndex>

#include "notebookwidget.h"
#include "notebookwidgetmodel.h"
#include "notebookwidgetsettingsstyle.h"

class NotebookWidgetSettingsViewPrivate;

/**
 * \brief View class for NotebookWidgetSettings.
 */
class ORGANISER_EXPORT NotebookWidgetSettingsView : public MWidgetView
{
  Q_OBJECT
  M_VIEW(NotebookWidgetModel, NotebookWidgetSettingsStyle)

public:
  /**
   * \brief Constructor.
   */
  NotebookWidgetSettingsView(NotebookWidget* controller);

  /**
   * \brief Destructor.
   */
  virtual ~NotebookWidgetSettingsView();

protected:
  //! \reimp
  virtual void applyStyle();
  virtual void setupModel();
  //! \reimp_end

private:
  Q_DISABLE_COPY(NotebookWidgetSettingsView);
  Q_DECLARE_PRIVATE(NotebookWidgetSettingsView);
  NotebookWidgetSettingsViewPrivate* d_ptr;

protected slots:
  //! \reimp
  virtual void updateData(const QList<const char*>& modifications);
  //! \reimp_end
  void notebookSelectorPopupHeaderClicked();
  void notebookSelectionChanged(const QModelIndex& index);

private slots:
};

#endif

