/* * This file is part of Harmattan Organiser GUI *
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 *
 * Contact: Andrey Moiseenko <andrey.moiseenko@nokia.com>
 *
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved. Copying,
 * including reproducing, storing, adapting or translating, any or all of
 * this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */

/**
 * @file
 * A skeleton for creating the private part of view.
 *
 * @author Markus Stenberg \<ext-markus.stenberg@nokia.com\>
 * @author Tuomas Toivonen \<ext-tuomas.1.toivonen@nokia.com\>
 */

#ifndef NOTEBOOKWIDGETSETTINGSVIEW_P_H
#define NOTEBOOKWIDGETSETTINGSVIEW_P_H

#include <MGridLayoutPolicy>
#include <MLayout>
#include <MButton>
#include <MLabel>
#include <MPopupList>

#include <QModelIndex>

class NotebookWidgetSettings;
class NotebookWidgetSettingsView;
class MyColorLabel;
class MList;

/**
 * \brief Private part of NotebookWidgetSettingsView.
 */
class NotebookWidgetSettingsViewPrivate
{
private:
  NotebookWidgetSettingsView* q_ptr;
  Q_DISABLE_COPY(NotebookWidgetSettingsViewPrivate);
  Q_DECLARE_PUBLIC(NotebookWidgetSettingsView);

public:
  /**
   * \brief Constructor.
   *
   * \param p Pointer to the public class.
   * \param controller Pointer to controller class instance.
   */
  NotebookWidgetSettingsViewPrivate(NotebookWidgetSettingsView* p, NotebookWidget* controller);

  /**
   * \brief Destructor.
   */
  ~NotebookWidgetSettingsViewPrivate();

  /**
   * \brief Update notebook id in the view based on model data.
   */
  void updateNotebookId();

  /**
   * \brief Update notebook name in the view based on model data.
   */
  void updateNotebookName();

  /**
   * \brief Update list of notebooks in the view based on model data.
   */
  void updateNotebookList();

  QStringList notebookIds();

  NotebookWidget* controller;

  /**
   * \brief Dialog to select notebook.
   */
  MDialog* notebookSelectorPopupListDialog;

  /**
   * \brief List of notebooks.
   */
  MList* notebookSelectorList;

  /**
   * \brief Color label for the notebook.
   */
  MyColorLabel* notebookColor;

  /**
   * \brief Label to show the notebook's name.
   */
  MLabel* notebookName;
};

#endif
