/* * This file is part of Harmattan Organiser GUI *
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 *
 * Contact: Andrey Moiseenko <andrey.moiseenko@nokia.com>
 *
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved. Copying,
 * including reproducing, storing, adapting or translating, any or all of
 * this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */
/**
 * @file
 * \brief This file defines the view for NotebookWidget.
 *
 * @author Mikko Herranen \<ext-mikko.herranen@nokia.com\>
 */
#ifndef NOTEBOOKWIDGETVIEW_H
#define NOTEBOOKWIDGETVIEW_H

#include <mwidgetview.h>
#include <QObject>

#include "notebookwidgetmodel.h"
#include "notebookwidgetstyle.h"

class NotebookWidget;
class NotebookWidgetViewPrivate;

/**
 * \brief View class for NotebookWidget.
 */
class NotebookWidgetView : public MWidgetView
{
  Q_OBJECT
  M_VIEW(NotebookWidgetModel, NotebookWidgetStyle)

public:
  /**
   * \brief Constructor.
   *
   * @param controller Pointer to the controller class.
   */
  NotebookWidgetView(NotebookWidget* controller);

  /**
   * \brief Destructor.
   */
  virtual ~NotebookWidgetView();

protected:
  NotebookWidgetViewPrivate* d_ptr;

  //! \reimp
  virtual void applyStyle();
  virtual void setupModel();
  //! \reimp_end

private:
  Q_DISABLE_COPY(NotebookWidgetView);
  Q_DECLARE_PRIVATE(NotebookWidgetView);

protected slots:
  //! \reimp
  virtual void updateData(const QList<const char*>& modifications);
  virtual void drawBackground(QPainter *painter, const QStyleOptionGraphicsItem *option) const;
  //! \reimp_end

  //void buttonClicked();

  void nameClicked();
};

#endif
