/* * This file is part of Harmattan Organiser GUI *
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 *
 * Contact: Andrey Moiseenko <andrey.moiseenko@nokia.com>
 *
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved. Copying,
 * including reproducing, storing, adapting or translating, any or all of
 * this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */
#ifndef NOTEBOOKWIDGETVIEW_P_H
#define NOTEBOOKWIDGETVIEW_P_H

class MultiStateWidget;
class NotebookWidget;
class MImageWidget;

/**
 * \brief Private part of NotebookWidgetView class.
 */
class NotebookWidgetViewPrivate
{
private:
  NotebookWidgetView* q_ptr;
  Q_DISABLE_COPY(NotebookWidgetViewPrivate);
  Q_DECLARE_PUBLIC(NotebookWidgetView);

public:

  /**
   * \brief Multistate widget states for local/remote calendar.
   */
  enum {
      LOCAL_NOTEBOOK,
      REMOTE_NOTEBOOK
  };

  /**
   * \brief Constructor.
   *
   * \param p Pointer to public class.
   * \param controller Pointer to controller class instance.
   */
  NotebookWidgetViewPrivate(NotebookWidgetView* p, NotebookWidget* controller);

  /**
   * \brief Update notebook name widgets.
   */
  void updateName();

  /**
   * \brief Update notebook color label widget.
   */
  void updateColor();

  /**
   * \brief Update the local/remote status of the notebook.
   */
  void updateAccount();

  /**
   * \brief Destructor.
   */
  ~NotebookWidgetViewPrivate();

  /**
   * \brief Initialize the class.
   */
  NotebookWidget* controller;

  /**
   * \brief Variable content of the notebook widget.
   */
  MultiStateWidget* content;

  /**
   * \brief Label for notebook name (local calendar).
   */
  MLabel* localNameLabel;

  /**
   * \brief Label for notebook name (local calendar).
   */
  MLabel* remoteNameLabel;

  /**
   * \brief Label for notebook's color.
   */
  MyColorLabel* notebookColorLabel;

  /**
   * \brief Icon for notebook.
   */
  MImageWidget* mainIcon;

};

#endif
