/* * This file is part of Harmattan Organiser GUI *
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 *
 * Contact: Andrey Moiseenko <andrey.moiseenko@nokia.com>
 *
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved. Copying,
 * including reproducing, storing, adapting or translating, any or all of
 * this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */
/**
 * @file
 * \brief This file contains the private part of NoteEditWidget
 * controller.
 *
 * @author Mikko Herranen \<ext-mikko.herranen@nokia.com\>
 */
#ifndef NOTEEDITWIDGET_P_H
#define NOTEEDITWIDGET_P_H

#include "noteeditwidget.h"

class KDateTime;
class NoteEditWidgetModel;

/**
 * \brief Private part of the NoteEditWidget controller.
 */
class NoteEditWidgetPrivate
{
public:
  /**
   * \brief Constructor.
   *
   * @param p Pointer to the public controller class.
   */
  NoteEditWidgetPrivate(NoteEditWidget* p);

  /**
   * \brief Destructor.
   */
  virtual ~NoteEditWidgetPrivate();

  /**
   * \brief Initialize.
   */
  void init();

  /**
   * \brief Returns true if the email address is valid.
   */
  static bool isValidEmail(const QString& email);

  /**
   * \brief Set participants of the note.
   *
   * @param participants A list of participants.
   */
  void setParticipants(const KCalCore::Attendee::List& participants);

  void setAttachments(const KCalCore::Attachment::List& attachments);

  /**
   * \brief The contents of the model we got from loading.
   */
  NoteEditWidgetModel loadedModel;

  /**
   * \brief Utility function to get a list of working days according
   * to current DUI locale. Note that the return value is already the
   * one used by the kcal (sunday<>monday offset)
   */
  QList<int> getWorkingDays();

  /**
   * \brief Similar utility to get (comparable) working days from a
   * RecurrenceRule. */
  QList<int> getWorkingDays(KCalCore::RecurrenceRule *rrule);

  /**
   * \brief Figure if the QTextDocument contains 'rich text' or not.
   */
  bool isRichText(const QString &text);
protected:
  Q_DECLARE_PUBLIC(NoteEditWidget);
  Q_DISABLE_COPY(NoteEditWidgetPrivate);
  NoteEditWidget* q_ptr;

  /**
   * \brief Indicates note is loading now
   */
  bool loading;

  /**
   * \brief Indicates note loaded or created
   */
  bool alreadyLoaded;

  /**
   * \brief Indicates current edit mode
   */
  NoteEditWidget::LoadMode loadMode;

  /**
   * \brief Start time when single occurence is edited
   */
  KDateTime startTime;
};

#endif
