/* * This file is part of Harmattan Organiser GUI *
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 *
 * Contact: Andrey Moiseenko <andrey.moiseenko@nokia.com>
 *
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved. Copying,
 * including reproducing, storing, adapting or translating, any or all of
 * this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */
#ifndef NOTEEDITWIDGETMODEL_H
#define NOTEEDITWIDGETMODEL_H

#include <kdatetime.h>
#include <MWidgetModel>
#include <QDateTime>
#include <QtLocation/QGeoCoordinate>
#include "incidence.h"
#include "incidencebase.h"
#include "organiser_export.h"

using namespace QtMobility;
using namespace KCalCore;

typedef KCalCore::Incidence::Status KCalStatus;


class ORGANISER_EXPORT NoteEditWidgetModel : public MWidgetModel
{
    Q_OBJECT
    M_MODEL(NoteEditWidgetModel)

public:
    // recurrence type - used for "recurrence" model field
    enum {
        OnlyOnce,
        EveryDay,
        EveryWorkingDay,
        EveryWeek,
        EveryMonth,
        EveryYear
    };

    // our participation status - used for "partStat" model field
    enum {
        Accepted,
        Declined,
        Tentative,
        NeedsAction
    };

    enum NoteType {
      Unset,
      Incidence,
      Todo,
      Journal,
      Event
    };
    
    NoteEditWidgetModel &operator=(const NoteEditWidgetModel& other);
  
    bool operator==(const NoteEditWidgetModel& other) const;

    bool operator!=(const NoteEditWidgetModel& other) const
    {
        return !(*this == other);
    }

    bool isJournal() const
    {
        return type() == Journal;
    }

    bool isTodo() const
    {
        return type() == Todo;
    }

    bool isEvent() const
    {
        return type() == Event;
    }

private:
    M_MODEL_PROPERTY(QString, noteId, NoteId, true, "")
    M_MODEL_PROPERTY(KDateTime, recurrenceId, RecurrenceId, true, KDateTime())
    M_MODEL_PROPERTY(NoteEditWidgetModel::NoteType, type, Type, true, Unset)
    M_MODEL_PROPERTY(QString, title, Title, true, "")
    M_MODEL_PROPERTY(QDateTime, startTime, StartTime, true, QDateTime())
    M_MODEL_PROPERTY(QDateTime, endTime, EndTime, true, QDateTime())
    M_MODEL_PROPERTY(bool, allDay, AllDay, true, false)
    M_MODEL_PROPERTY(bool, hasAlarm, HasAlarm, true, true)
    M_MODEL_PROPERTY(int, alarmOffsetMinutes, AlarmOffsetMinutes, true, 15)
    M_MODEL_PROPERTY(bool, hasRSVP, HasRSVP, true, false)
    M_MODEL_PROPERTY(int, partStat, PartStat, true, NeedsAction)
    M_MODEL_PROPERTY(QString, responseBody, ResponseBody, true, "")
    M_MODEL_PROPERTY(int, recurrence, Recurrence, true, OnlyOnce)
    M_MODEL_PROPERTY(QDateTime, recurrenceEndTime, RecurrenceEndTime, true, QDateTime())
    M_MODEL_PROPERTY(QString, location, Location, true, "")
    M_MODEL_PROPERTY(QGeoCoordinate, coordinate, Coordinate, true, QGeoCoordinate())
    M_MODEL_PROPERTY(QString, description, Description, true, "")
    M_MODEL_PROPERTY(QStringList, participants, Participants, true, QStringList())
    M_MODEL_PROPERTY(QStringList, participantsSms, ParticipantsSms, true, QStringList())
    M_MODEL_PROPERTY(QStringList, participantsName, ParticipantsName, true, QStringList())
    M_MODEL_PROPERTY(QStringList, participantsSmsName, ParticipantsSmsName, true, QStringList())
    M_MODEL_PROPERTY(QStringList, attachments, Attachments, true, QStringList())
    M_MODEL_PROPERTY(QString, notebookId, NotebookId, true, "")
    M_MODEL_PROPERTY(QString, notebookName, NotebookName, true, "")
    M_MODEL_PROPERTY(QString, notebookColor, NotebookColor, true, "")
    M_MODEL_PROPERTY(QDateTime, dueDate, DueDate, true, QDateTime())
    M_MODEL_PROPERTY(int, dueDateAlarmDaysBefore, DueDateAlarmDaysBefore, true, -1)
    M_MODEL_PROPERTY(QTime, dueDateAlarmTime, DueDateAlarmTime, true, QTime())
    M_MODEL_PROPERTY(KCalStatus, inviStatus, InviStatus, true, Incidence::StatusNone)
    M_MODEL_PROPERTY(QString, organizerPersonName, OrganizerPersonName, true, QString())
    M_MODEL_PROPERTY(QString, organizerPersonEmail, OrganizerPersonEmail, true, QString())
    M_MODEL_PROPERTY(bool, completed, Completed, true, false)
};

#endif
