/* * This file is part of Harmattan Organiser GUI *
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 *
 * Contact: Andrey Moiseenko <andrey.moiseenko@nokia.com>
 *
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved. Copying,
 * including reproducing, storing, adapting or translating, any or all of
 * this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */
/**
 * @file
 * \brief This file contains the private part of NoteListWidget controller.
 *
 * @author Mikko Herranen \<ext-mikko.herranen@nokia.com\>
 */
#ifndef NOTELISTWIDGET_P_H
#define NOTELISTWIDGET_P_H

#include <QPointF>
#include <QString>

#include <MStylableWidget>

class QTimer;
class MLabel;
class MSeparator;
class MPannableViewport;
class NoteListWidget;
class NoteWidgetCreator;
class AbstractNoteLoader;
class NoteWidgetHeaderCreator;

/**
 * \brief Note header widget.
 */
class NoteListHeaderWidget : public MStylableWidget
{
    Q_OBJECT

public:

    /**
     * \brief Constructs a new header widget.
     */
    NoteListHeaderWidget();

    /**
     * \brief Get the text of the header.
     */
    QString text() const;

    /**
     * \brief Set the text of the header.
     */
    void setText(const QString& text);

    /**
     * \brief Get the panel style name of the header.
     */
    QString panelStyleName() const;

    /**
     * \brief Set the panel style name of the header.
     */
    void setPanelStyleName(const QString& name);

    /**
     * \brief Get the label style name of the header.
     */
    QString labelStyleName() const;

    /**
     * \brief Set the lebel style name of the header.
     */
    void setLabelStyleName(const QString& name);

private:

    MStylableWidget* panel;

    MLabel* label;
};

/**
 * \brief Private part of the NoteListWidget controller.
 */
class NoteListWidgetPrivate
{
public:
  /**
   * \brief Constructor.
   *
   * @param p Pointer to the public controller class.
   */
  NoteListWidgetPrivate(NoteListWidget* p);

  /**
   * \brief Destructor.
   */
  virtual ~NoteListWidgetPrivate();

  void init(AbstractNoteLoader* loader, bool showGroups, bool customGroups);

  /**
   * \brief Set to true if the next call to setGeometry needs to adjust
   * the list position.
   */
  enum MoveDirection {
      EMoveUninit,
      EMoveUp,
      EMoveDown
  };

  bool adjustGeom;
  bool ignoreOneEvent;
  bool listScrolling;
  bool pointerReleased;
  MPannableViewport* parentViewport;
  QTimer* ensureScrollingCall;
  QPointF viewportPosition;
  MoveDirection moveDirection;
  NoteWidgetCreator* p_creator;
  NoteWidgetHeaderCreator* p_headerCreator;
  QString itemStyleName;
  quint16 refreshEnabledCounter;
private:
  Q_DECLARE_PUBLIC(NoteListWidget);
  Q_DISABLE_COPY(NoteListWidgetPrivate);
  NoteListWidget* q_ptr;

};

#endif
