/* * This file is part of Harmattan Organiser GUI *
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 *
 * Contact: Andrey Moiseenko <andrey.moiseenko@nokia.com>
 *
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved. Copying,
 * including reproducing, storing, adapting or translating, any or all of
 * this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */
#ifndef NOTELISTWIDGETWRAPPER_H
#define NOTELISTWIDGETWRAPPER_H

#include <MWidget>

#include "organiserutility.h"
#include "organiser_export.h"

class NoteListWidget;
class NoteListWidgetWrapperPrivate;

/**
 * \brief A widget used for displaying a list of notes  with
*  additional inforamational label if there is no items in list.
 */
class ORGANISER_EXPORT NoteListWidgetWrapper : public MWidget, public VisibilityNotificationIF
{
    Q_OBJECT

public:

    /**
    * \brief Constructor.
    *
    * \param widget NoteListWidget to be wrapped.
    */
    NoteListWidgetWrapper(NoteListWidget* widget);

    /**
    * \brief Note list which is wrapped
    *
    * \return Wrapped list
    */
    NoteListWidget* noteList();

    /**
    * \brief Text of label which will be shown when list is empty
    *
    * \return Text which will be shown
    */
    QString emptyListLabelText() const;

    /**
    * \brief Set text of label which will be shown when list is empty
    *
    * \param text Text which will be shown
    */
    void setEmptyListLabelText(const QString& text);

    /**
    * \brief Style of label which will be shown when list is empty
    *
    * \return Text which will used to show label
    */
    QString emptyListLabelStyle() const;

    /**
    * \brief Set style of label which will be shown when list is empty
    *
    * \param text Text which will used to show label
    */
    void setEmptyListLabelStyle(const QString& name);

    //! \reimp

    virtual void updateContent(int mask);

    virtual int updateTypeMask();

    //! \reimp_end

private slots:

    /**
    * \brief Called when content is updated.
    *
    * Used mainly when NoteListWidget is not the main widget for a page.
    */
    void updateLayout(bool showEmptyLabel);

private:

    Q_DISABLE_COPY(NoteListWidgetWrapper);
    Q_DECLARE_PRIVATE(NoteListWidgetWrapper);
    NoteListWidgetWrapperPrivate* d_ptr;
};

#endif
