/* * This file is part of Harmattan Organiser GUI *
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 *
 * Contact: Andrey Moiseenko <andrey.moiseenko@nokia.com>
 *
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved. Copying,
 * including reproducing, storing, adapting or translating, any or all of
 * this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */
/**
 * @file
 * \brief This file defines the NoteWidgetITemModel class.
 *
 * @author Mikko Herranen \<ext-mikko.herranen@nokia.com\>
 */
#ifndef NOTEWIDGETITEMMODEL_H
#define NOTEWIDGETITEMMODEL_H

#include <QAbstractItemModel>
#include <extendedcalendar.h>
#include <incidence.h>
#include <journal.h>
#include "organiser_export.h"

class AbstractNoteLoader;
class NoteWidgetItemModelPrivate;

/**
 * \brief Item model class for creating note widgets out of notes.
 */
class NoteWidgetItemModel : public QAbstractItemModel
{
  Q_OBJECT

public:
  /**
   * \brief Constructor.
   *
   * \param loader The loader to be used for populating the model on
   * demand. The loader will be freed alongside the
   * NoteWidgetItemModel.
   */
  NoteWidgetItemModel(AbstractNoteLoader* loader);

  /**
   * \brief Destructor.
   */
  ~NoteWidgetItemModel();

  //! \reimp
  virtual Qt::ItemFlags flags ( const QModelIndex& index ) const;
  virtual QModelIndex index(int row, int column, const QModelIndex& parent = QModelIndex()) const;
  virtual QModelIndex parent(const QModelIndex& index) const;
  virtual int rowCount(const QModelIndex& parent) const;
  virtual int columnCount(const QModelIndex& parent) const;

  /**
   * \copydoc QAbstractItemModel::data(const QModelIndex&, int)
   *
   * Note: A 0-pointer is used as a placeholder for a 'new' button.
   */
  virtual QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const;

  enum LoadMoreRetVal {
    ItemsPrepended = 1,
    ItemsAppended = 2
  };

  /**
   * \brief Load more notes.
   *
   * \param firstVisible Index of the first visible note widget.
   * \param lastVisible Index of the last visible note widget.
   *
   * \return A bitwise-or'd value of LoadMoreRetVal flags.
   */
  int loadMore(const QModelIndex& firstVisible, const QModelIndex& lastVisible);

  int loadMoreTop();
  int loadMoreBottom();
  bool isLastIncidence(const QModelIndex& last) const;

  /**
   * \brief Reload notes.
   */
  void reload();

  int incidenceCount();

private:
  NoteWidgetItemModelPrivate* d_ptr;
  Q_DISABLE_COPY(NoteWidgetItemModel);
  Q_DECLARE_PRIVATE(NoteWidgetItemModel);

};

Q_DECLARE_METATYPE(KCalCore::Incidence::Ptr);

#endif
