/* * This file is part of Harmattan Organiser GUI *
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 *
 * Contact: Andrey Moiseenko <andrey.moiseenko@nokia.com>
 *
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved. Copying,
 * including reproducing, storing, adapting or translating, any or all of
 * this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */
/**
 * @file
 * \brief This file defines the private part of NoteWidgetListItemView class.
 *
 * @author Mikko Herranen \<ext-mikko.herranen@nokia.com\>
 */
#ifndef NOTEWIDGETLISTITEMVIEW_P_H
#define NOTEWIDGETLISTITEMVIEW_P_H

#include <QObject>
#include <MLabel>

class MGridLayoutPolicy;
class MLayout;
class MStylableWidget;
class NoteWidget;
class NoteWidgetListItemView;

/**
 * \brief Private part of NoteWidgetListItemView class.
 */
class NoteWidgetListItemViewPrivate
{
public:
  /**
   * \brief Constructor.
   *
   * \param p Pointer to public class instance.
   * \param controller Pointer to controller class instance.
   */
  NoteWidgetListItemViewPrivate(NoteWidgetListItemView* p, NoteWidget* controller);

  /**
   * \brief Destructor.
   */
  virtual ~NoteWidgetListItemViewPrivate();

  /**
   * \brief Main layout of the widget.
   */
  MLayout* layout;

  /**
   * \brief Layout policy for 'title and subtitle' mode.
   */
  MGridLayoutPolicy* titleAndSubtitlePolicy;

  /**
   * \brief Layout policy for single title mode.
   */
  MGridLayoutPolicy* singleTitlePolicy;

  /**
   * \brief Layout policy for 'title, subtitle and subtext' mode.
   */
  MGridLayoutPolicy* titleSubtitleAndTextPolicy;

  /**
   * \brief Layout policy for 'title and subtext' mode.
   */
  MGridLayoutPolicy* titleAndTextPolicy;

  /**
   * \brief Label for displaying the title.
   */
  MLabel* titleLabel;

  MStylableWidget* titleContainer;

  /**
   * \brief Label for displaying the subtitle.
   */
  MLabel* subtitleLabel;

  /**
   * \brief Label for displaying the subtext.
   */
  MLabel* subTextLabel;

  /**
   * \brief Pointer to controller class instance.
   */
  NoteWidget* controller;


  void updateAlarm();

private:
  Q_DECLARE_PUBLIC(NoteWidgetListItemView);
  Q_DISABLE_COPY(NoteWidgetListItemViewPrivate);
  NoteWidgetListItemView* q_ptr;

};

#endif
