/* * This file is part of Harmattan Organiser GUI *
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 *
 * Contact: Andrey Moiseenko <andrey.moiseenko@nokia.com>
 *
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved. Copying,
 * including reproducing, storing, adapting or translating, any or all of
 * this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */
#ifndef NOTEWIDGETMODEL_H
#define NOTEWIDGETMODEL_H

#include <MWidget>
#include <MWidgetModel>
#include <QColor>
#include <QDateTime>
#include <incidence.h>

#include "db_instance.h"
#include "organiser_export.h"

typedef KCalCore::Incidence::Status KCalStatus;

class ORGANISER_EXPORT NoteWidgetModel : public MWidgetModel
{
    Q_OBJECT
    M_MODEL(NoteWidgetModel)

public:
    enum NoteType {
      Unset,
      Incidence,
      Todo,
      Journal
    };
    KCalCore::Incidence::Ptr note() const
    {
        return DbInstance::instance().incidence(uid(), recurrenceId());
    }
private:
    M_MODEL_PROPERTY(NoteWidgetModel::NoteType, type, Type, true, Unset)
    M_MODEL_PROPERTY(QString, uid, Uid, true, QString())
    M_MODEL_PROPERTY(KDateTime, recurrenceId, RecurrenceId, true, KDateTime())
    M_MODEL_PROPERTY(QColor, color, Color, true, QColor())
    M_MODEL_PROPERTY(QDateTime, startTime, StartTime, true, QDateTime())
    M_MODEL_PROPERTY(QDateTime, endTime, EndTime, true, QDateTime())
    M_MODEL_PROPERTY(bool, allDay, AllDay, true, false)
    M_MODEL_PROPERTY(QString, title, Title, true, "")
    M_MODEL_PROPERTY(QString, location, Location, true, "")
    M_MODEL_PROPERTY(QString, description, Description, true, "")
    M_MODEL_PROPERTY(QDateTime, lastModified, LastModified, true, QDateTime())
    M_MODEL_PROPERTY(QDateTime, created, Created, true, QDateTime())
    M_MODEL_PROPERTY(bool, hasAlarm, HasAlarm, true, false)
    M_MODEL_PROPERTY(bool, selected, Selected, true, false)
    M_MODEL_PROPERTY(bool, pressed, Pressed, true, false)
    M_MODEL_PROPERTY(bool, squeezed, Squeezed, true, false)
    M_MODEL_PROPERTY(QDateTime, dueDate, DueDate, true, QDateTime())
    M_MODEL_PROPERTY(bool, completed, Completed, true, false)
    M_MODEL_PROPERTY(bool, tentative, Tentative, true, false)
    M_MODEL_PROPERTY(QString, deleteNoteShortTitle, DeleteNoteShortTitle, true, "")
    M_MODEL_PROPERTY(bool, readOnly, ReadOnly, true, false)
};

#endif
