/* * This file is part of Harmattan Organiser GUI *
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 *
 * Contact: Andrey Moiseenko <andrey.moiseenko@nokia.com>
 *
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved. Copying,
 * including reproducing, storing, adapting or translating, any or all of
 * this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */
/**
 * @file
 * This file defines the Timer Service that provides timers for calendar use.
 *
 * @author Mikko Herranen \<ext-mikko.herranen@nokia.com\>
 */
#ifndef TIMERSERVICE_H
#define TIMERSERVICE_H

#include <QObject>
#include "organiser_export.h"

class TimerServicePrivate;

/**
 * \brief A class that provides timer notifications, such as dayChanged(),
 * for calendar use.
 */
class ORGANISER_EXPORT TimerService : public QObject
{
  Q_OBJECT

    static TimerService *mSingleton;
public:
  /**
   * \brief Returns reference to the singleton instance.
   */
  static TimerService& instance();

  static void destroy();

protected:
  //! \reimp
  virtual void connectNotify(const char* signal);
  virtual void disconnectNotify(const char* signal);
  //! \reimp_end

private:
  Q_DISABLE_COPY(TimerService);
  Q_DECLARE_PRIVATE(TimerService);

#ifdef UNIT_TEST
public:
#endif
  /**
   * \brief Constructor.
   */
  TimerService();

  /**
   * \brief Destructor.
   */
  ~TimerService();

  /**
   * \brief Pointer to the private class.
   */
  TimerServicePrivate* d_ptr;

signals:
  /**
   * \brief Emitted when the minute has changed.
   */
  void minuteChanged();

  /**
   * \brief Emitted when the hour has changed.
   */
  void hourChanged();

  /**
   * \brief Emitted when the day has changed.
   */
  void dateChanged();

public slots:
  /**
   * \brief Enable the timerService
   */
  void enable();

  /**
   * \brief Disable teh timerService
   */
  void disable();

#ifdef UNIT_TEST
public slots:
#else
private slots:
#endif
  /**
   * \brief Called when the internal timer expires.
   */
  void timerExpired();

  void qmTimeOrSettingsChanged();

};

#endif
