/* * This file is part of Harmattan Organiser GUI *
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 *
 * Contact: Andrey Moiseenko <andrey.moiseenko@nokia.com>
 *
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved. Copying,
 * including reproducing, storing, adapting or translating, any or all of
 * this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */
/**
 * @file
 * This file defines the Timer Service that provides timers for calendar use.
 *
 * @author Mikko Herranen \<ext-mikko.herranen@nokia.com\>
 */
#ifndef TIMERSERVICE_P_H
#define TIMERSERVICE_P_H

#include <QDateTime>
#include <QObject>

namespace MeeGo {
  class QmTime;
};

class TimerService;
class QTimer;

/**
 * \brief Private part of TimerService.
 */
class TimerServicePrivate
{
public:
  /**
   * \brief Constructor.
   *
   * @param p Pointer to the public class.
   */
  TimerServicePrivate(TimerService* p);

  /**
   * \brief Destructor.
   */
  virtual ~TimerServicePrivate();

  /**
   * \brief Get the current DateTime. Override in unit test class.
   *
   * \return Current DateTime.
   */
  virtual QDateTime currentDateTime();

  /**
   * \brief Schedule the next wakeup.
   *
   * Set the timer to expire when the next time change notification has to
   * be delivered.
   */
  void scheduleNextWakeup();

  /**
   * \brief Internal timer.
   */
  QTimer* timer;

  /**
   * \brief Previous recorded time.
   */
  QDateTime time;

  /**
   * \brief Object for interacting with system clock/settings.
   */
  MeeGo::QmTime* qmTime;

private:
  Q_DECLARE_PUBLIC(TimerService);
  Q_DISABLE_COPY(TimerServicePrivate);
  TimerService* q_ptr;

};

#endif
